==> MIDITrail-Ver.1.0.0src.zip: MIDITrail/MIDITrail/MTScene.h <==
//******************************************************************************
//
// MIDITrail / MTScene
//
// MIDITrail V[NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include "DXScene.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// MIDITrail V[NX
//******************************************************************************
class MTScene : public DXScene
{
public:

	//RXgN^^fXgN^
	MTScene(void);
	virtual ~MTScene(void);

	//̎擾
	virtual const TCHAR* GetName();

	//
	virtual int Create(
					HWND hWnd,
					LPDIRECT3DDEVICE9 pD3DDevice,
					SMSeqData* pSeqData
				);

	//ϊ
	virtual int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	virtual int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	virtual void Release();

	//FPSo^
	virtual void SetFPS(double fps);

	//EBhENbNCxgM
	virtual int OnWindowClicked(
					unsigned long button,
					unsigned long wParam,
					unsigned long lParam
				);

	//tJnCxgM
	virtual int OnPlayStart();

	//tICxgM
	virtual int OnPlayEnd();

	//V[PTbZ[WM
	virtual int OnRecvSequencerMsg(
					unsigned long wParam,
					unsigned long lParam
				);

	//߂
	virtual int Rewind();

	//_擾
	virtual void GetDefaultViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	virtual void GetViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	virtual void SetViewpoint(D3DXVECTOR3 vector, float phi, float theta);

	//_Zbg
	virtual void ResetViewpoint();

};

==> MIDITrail-Ver.1.0.3src.zip: MIDITrail/MIDITrail/MTScene.h <==
//******************************************************************************
//
// MIDITrail / MTScene
//
// MIDITrail V[NX
//
// Copyright (C) 2010 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#pragma once

#include "DXScene.h"
#include "SMIDILib.h"

using namespace SMIDILib;


//******************************************************************************
// MIDITrail V[NX
//******************************************************************************
class MTScene : public DXScene
{
public:

	enum EffectType {
		EffectPianoKeyboard,
		EffectRipple,
		EffectPitchBend
	};

public:

	//RXgN^^fXgN^
	MTScene(void);
	virtual ~MTScene(void);

	//̎擾
	virtual const TCHAR* GetName();

	//
	virtual int Create(
					HWND hWnd,
					LPDIRECT3DDEVICE9 pD3DDevice,
					SMSeqData* pSeqData
				);

	//ϊ
	virtual int Transform(LPDIRECT3DDEVICE9 pD3DDevice);

	//`
	virtual int Draw(LPDIRECT3DDEVICE9 pD3DDevice);

	//j
	virtual void Release();

	//FPSo^
	virtual void SetFPS(double fps);

	//EBhENbNCxgM
	virtual int OnWindowClicked(
					unsigned long button,
					unsigned long wParam,
					unsigned long lParam
				);

	//tJnCxgM
	virtual int OnPlayStart();

	//tICxgM
	virtual int OnPlayEnd();

	//V[PTbZ[WM
	virtual int OnRecvSequencerMsg(
					unsigned long wParam,
					unsigned long lParam
				);

	//߂
	virtual int Rewind();

	//_擾
	virtual void GetDefaultViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	virtual void GetViewpoint(D3DXVECTOR3* pVector, float* pPhi, float* pTheta);
	virtual void SetViewpoint(D3DXVECTOR3 vector, float phi, float theta);

	//_Zbg
	virtual void ResetViewpoint();

	//\ʐݒ
	virtual void SetEffect(EffectType type, bool isEnable);

};
